==> hadoop-client-api-3.3.4-sources.jar: org/apache/hadoop/ha/HealthCheckFailedException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.ha;

import java.org.apache.hadoop.shaded.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;

/**
 * Exception thrown to indicate that health check of a service failed.
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public class HealthCheckFailedException extends IOException {
  private static final long serialVersionUID = 1L;

  public HealthCheckFailedException(final String message) {
    super(message);
  }
  
  public HealthCheckFailedException(String message, Throwable cause) {
    super(message, cause);
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/ha/HealthCheckFailedException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.ha;

import java.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;

/**
 * Exception thrown to indicate that health check of a service failed.
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public class HealthCheckFailedException extends IOException {
  private static final long serialVersionUID = 1L;

  public HealthCheckFailedException(final String message) {
    super(message);
  }
  
  public HealthCheckFailedException(String message, Throwable cause) {
    super(message, cause);
  }
}
